"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
function getFileExtension(filePath) {
    const pathParts = /^.+\.([^.]+)$/.exec(filePath);
    if (pathParts && pathParts.length > 1) {
        return pathParts[1];
    }
    return null;
}
exports.getFileExtension = getFileExtension;
function getPathWithoutExtension(filePath, extension) {
    let pathWithoutExtension = filePath;
    if (extension) {
        pathWithoutExtension = filePath.substr(0, filePath.length - (extension.length + 1));
    }
    return pathWithoutExtension;
}
exports.getPathWithoutExtension = getPathWithoutExtension;
function resolveFile(filePath) {
    const extension = getFileExtension(filePath);
    const pathWithoutExtension = getPathWithoutExtension(filePath, extension);
    switch (extension) {
        case 'js': {
            return require.resolve(pathWithoutExtension + '.js');
        }
        case 'json': {
            return require.resolve(pathWithoutExtension + '.json');
        }
        default: {
            if (fs_1.default.existsSync(filePath + `.js`)) {
                return require.resolve(filePath + '.js');
            }
            if (fs_1.default.existsSync(filePath + `.json`)) {
                return require.resolve(filePath + '.json');
            }
            if (extension) {
                throw Error(`cannot require.resolve() module with extension '${extension}'`);
            }
        }
    }
}
exports.resolveFile = resolveFile;
function requireFile(filePath) {
    const extension = getFileExtension(filePath);
    const pathWithoutExtension = getPathWithoutExtension(filePath, extension);
    switch (extension) {
        case 'js': {
            return require(pathWithoutExtension + '.js');
        }
        case 'json': {
            return require(pathWithoutExtension + '.json');
        }
        default: {
            if (fs_1.default.existsSync(filePath + `.js`)) {
                return require(filePath + '.js');
            }
            if (fs_1.default.existsSync(filePath + `.json`)) {
                return require(filePath + '.json');
            }
            if (extension) {
                throw Error(`cannot require() module with extension '${extension}'`);
            }
        }
    }
}
exports.requireFile = requireFile;
//# sourceMappingURL=fileUtils.js.map